
typedef Imlib_Image * Imlib2__Imlib_Image;
typedef Pixmap   Imlib2__Pixmap;
typedef Drawable  Imlib2__Drawable;
typedef Visual  * Imlib2__Visual;
typedef Colormap Imlib2__Colormap;
typedef Display * Imlib2__Display;
typedef Imlib_Font * Imlib2__Imlib_Font;
typedef Imlib_Color_Modifier * Imlib2__Imlib_Color_Modifier;
typedef Imlib_Color_Range * Imlib2__Imlib_Color_Range;

